lib_versions: Return library version information for GDAL and its...

View source: R/gdal_helpers.R

lib_versionsR Documentation

Return library version information for GDAL and its dependencies

Description

lib_versions() returns a named list of library version information for GDAL and its major dependencies, currently PROJ and GEOS. It provides library versions in a consistent format, as an alternative to the separate gdal_version(), proj_version() and geos_version().

Usage

lib_versions()

Value

A named list with elements "gdal", "proj" and "geos", each containing a named list with the following elements:

  • "name": character string version as "major.minor.patch"

  • "major": integer major version number

  • "minor": integer minor version number

  • "patch": integer patch version number

See Also

gdal_version(), proj_version(), geos_version()

Examples

lib_versions()

gdalraster documentation built on May 4, 2026, 9:06 a.m.