| lib_versions | R Documentation |
lib_versions() returns a named list of library version information for
GDAL and its major dependencies, currently PROJ and GEOS. It provides library
versions in a consistent format, as an alternative to the separate
gdal_version(), proj_version() and geos_version().
lib_versions()
A named list with elements "gdal", "proj" and "geos", each
containing a named list with the following elements:
"name": character string version as "major.minor.patch"
"major": integer major version number
"minor": integer minor version number
"patch": integer patch version number
gdal_version(), proj_version(), geos_version()
lib_versions()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.